@@ -18,8 +18,8 @@ import sys
 import re
 
 from calculate.lib.cl_lang import setLocalTranslate
-from calculate.core.server.loaded_methods import LoadedMethods
-from calculate.core.server.func import uniq
+from ..server.loaded_methods import LoadedMethods
+from ..server.func import uniq
 from calculate.lib.utils.files import readFile
 
 _ = lambda x: x
@@ -63,14 +63,13 @@ class VariableClCoreGroup(Variable):
                   'digits and underline symbols') + '\n' +
                 _('The group name must consist of 2 to 20 symbols'))
         group_rights = self.Get('cl_core_group_rights_path')
-
         if group == 'all':
             return
         t = readFile(group_rights)
         find = False
         for line in t.splitlines():
             words = line.split()
-            if words[0].startswith('#'):
+            if not words or words[0].startswith('#'):
                 continue
             if group == words[0]:
                 find = True
