@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
+ 
 import sys
 
 from calculate.lib.datavars import VariableError, DataVarsError
@@ -31,23 +31,23 @@ from .server import groups as groups
 from .server import request as request
 from . import set_vars
 from .backup import Backup, BackupError
-from calculate.core.utils.cl_backup import ClBackupAction
-from calculate.core.utils.cl_backup_restore import ClBackupRestoreAction
-from calculate.core.server.func import WsdlBase
-from calculate.core.utils.cl_core_setup import ClCoreSetupAction
-from calculate.core.utils.cl_core_patch import ClCorePatchAction
-from calculate.core.utils.cl_config import ClConfigAction
-from calculate.core.utils.cl_core_dispatch import ClCoreDispatchAction
-from calculate.core.utils.cl_core_view_cert import ClCoreViewCert
-from calculate.core.utils.cl_core_group import (
+from .utils.cl_backup import ClBackupAction
+from .utils.cl_backup_restore import ClBackupRestoreAction
+from .server.func import WsdlBase
+from .utils.cl_core_setup import ClCoreSetupAction
+from .utils.cl_core_patch import ClCorePatchAction
+from .utils.cl_config import ClConfigAction
+from .utils.cl_core_dispatch import ClCoreDispatchAction
+from .utils.cl_core_view_cert import ClCoreViewCert
+from .utils.cl_core_group import (
     ClCoreGroupShow, ClCoreGroupMod, ClCoreGroupAdd, ClCoreGroupDel)
-from calculate.core.utils.cl_core_request import (
+from .utils.cl_core_request import (
     ClCoreRequestShow, ClCoreRequestConfirm, ClCoreRequestDel)
-from calculate.core.utils.cl_core_variables import (ClCoreVariables,
+from .utils.cl_core_variables import (ClCoreVariables,
                                                     ClCoreVariablesShow)
-from calculate.core.utils.cl_core_custom import ClCoreCustomAction
-from calculate.core.utils.cl_core_restart import ClCoreRestartAction
-from calculate.core.variables.action import Actions
+from .utils.cl_core_custom import ClCoreCustomAction
+from .utils.cl_core_restart import ClCoreRestartAction
+from .variables.action import Actions
 
 
 class Wsdl(WsdlBase):
